@@ -51,7 +51,7 @@ class FfmpegProcess:
         eta_string = "unknown"
         ffmpeg_stderr = ""
 
-        print("Running FFmpeg...")
+        #print("Running FFmpeg...")
 
         with open(ffmpeg_output_file, "a") as f:
             self._process = subprocess.Popen(
